/*
 * Copyright (C) 2010 SHARP Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.co.sharp.android.SampleIrrc;

import jp.co.sharp.android.io.irrc.IrRemoteController;
import jp.co.sharp.android.io.irrc.IrRemoteControllerException;
import jp.co.sharp.android.io.irrc.IrRemoteControllerFrame;
import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;

/**
 * IrRemoteController/IrRemoteControllerFrameを使用したサンプルである。<BR>
 * ダミーのリモコンデータからダミーのフレームデータを送信する。<BR>
 * ダミーデータのため正常な動作は確認できないが、<BR>
 * 実際に機器が動作する恐れがあるため、利用時には注意すること。
 */
public class SampleIrrc extends Activity {
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);

        Button button01 = (Button) findViewById(R.id.Button01);
        button01.setText("send");
        button01.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View arg0) {
                Send();
            }
        });
    }

    /**
     * ---波形情報---<br>
     * キャリア high=120, low=150<br>
     * 論理パルス0 PPM変調High-Low, high=100, low=500<br>
     * 論理パルス1 PPM変調High-Low, high=200, low=800<br>
     *
     * ---フレーム1---<br>
     * リーダー high=50, low=300<br>
     * データ 0x137E, length=15<br>
     * トレーラー high=80<br>
     * フレーム長 30000<br>
     * 繰り返し 1<br>
     *
     * ---フレーム2---<br>
     * リーダー high=50, low=300<br>
     * データ 0xEC80, length=15<br>
     * トレーラー high=80<br>
     * フレーム長 30000<br>
     * 繰り返し 1<br>
     *
     * ---送信---<br>
     * 繰り返し 2<br>
     */
    void Send() {
        /* リモコンデータの作成 */
        IrRemoteController rc = null;
        try {
            rc = new IrRemoteController(SampleIrrc.this); /* ★Addon用API使用箇所★ */
        } catch (NullPointerException e) {
        } catch (RuntimeException e) {
        }
        if (rc != null) {
            /* 波形情報の設定 */
            try {
                /* キャリア　★Addon用API使用箇所★ */
                rc.setCarrier(120, 150);
            } catch (IllegalArgumentException e) {
            }

            try {
                /* 論理パルス0　★Addon用API使用箇所★ */
                rc.setPulse0(IrRemoteController.PPM_HIGH_LOW, 100, 500);
            } catch (IllegalArgumentException e) {
            }
            try {
                /* 論理パルス1　★Addon用API使用箇所★ */
                rc.setPulse1(IrRemoteController.PPM_HIGH_LOW, 200, 800);
            } catch (IllegalArgumentException e) {
            }

            /* フレーム１の作成　★Addon用API使用箇所★ */
            IrRemoteControllerFrame frame1 = new IrRemoteControllerFrame();
            try {
                /* リーダー　★Addon用API使用箇所★ */
                frame1.setLeader(50, 300);
            } catch (IllegalArgumentException e) {
            }
            try {
                /* データ　★Addon用API使用箇所★ */
                frame1.setFrameData(new byte[] { 0x13, 0x7E }, 15);
            } catch (NullPointerException e) {
            } catch (IllegalArgumentException e) {
            }
            try {
                /* トレーラー　★Addon用API使用箇所★ */
                frame1.setTrailer(80);
            } catch (IllegalArgumentException e) {
            }
            try {
                /* フレーム長　★Addon用API使用箇所★ */
                frame1.setFrameLength(30000);
            } catch (IllegalArgumentException e) {
            }
            try {
                /* 繰り返し回数　★Addon用API使用箇所★ */
                frame1.setRepeatCount(1);
            } catch (IllegalArgumentException e) {
            }

            /* フレーム2の作成　★Addon用API使用箇所★ */
            IrRemoteControllerFrame frame2 = new IrRemoteControllerFrame();
            try {
                /* リーダー　★Addon用API使用箇所★ */
                frame2.setLeader(50, 300);
            } catch (IllegalArgumentException e) {
            }
            try {
                /* データ　★Addon用API使用箇所★ */
                frame2.setFrameData(new byte[] { (byte) 0xEC, (byte) 0x80 }, 15);
            } catch (NullPointerException e) {
            } catch (IllegalArgumentException e) {
            }
            try {
                /* トレーラー　★Addon用API使用箇所★ */
                frame2.setTrailer(80);
            } catch (IllegalArgumentException e) {
            }
            try {
                /* フレーム長　★Addon用API使用箇所★ */
                frame2.setFrameLength(30000);
            } catch (IllegalArgumentException e) {
            }
            try {
                /* 繰り返し回数　★Addon用API使用箇所★ */
                frame2.setRepeatCount(1);
            } catch (IllegalArgumentException e) {
            }
            /* ブロックデータの作成　★Addon用API使用箇所★ */
            IrRemoteControllerFrame[] block = new IrRemoteControllerFrame[] {
                    frame1, frame2 };
            try {
                /* ブロックデータの送信　★Addon用API使用箇所★ */
                rc.send(block, 2);
            } catch (NullPointerException e) {
            } catch (IllegalArgumentException e) {
            } catch (IrRemoteControllerException e) {
            }
        }
    }
}